/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Annozilla.
 *
 * The Initial Developer of the Original Code is
 * Matthew Wilson <matthew@mjwilson.demon.co.uk>.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *    Doug Daniels <rainking@alumni.rice.edu>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * Verify disk space in kilobytes.
 */
function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if (spaceAvailable < spaceRequired)
  {
    logComment("Insufficient disk space: " + dirPath);
    logComment(" required: " + spaceRequired + "K");
    logComment(" available: " + spaceAvailable + "K");
    return false;
  }
  else {
      return true;
  }
}

// main code block

var err;
var packageName = "annotations"
var gVersion = "0.2.4";
var srDest = 51;

var err = initInstall("Annotations", packageName, gVersion);
logComment("initInstall: " + err);

var fProgram = getFolder("Program");
var fChrome = getFolder("Chrome");
var fComponents = getFolder("Components");
logComment("fProgram: " + fProgram);
logComment("fChrome: " + fChrome);
logComment("fComponents: " + fComponents);

if (verifyDiskSpace(fProgram, srDest)) {

    err = addDirectory("", "components", fComponents, "");
    logComment("addDirectory for components: " + err);
    if (err != SUCCESS) {
	cancelInstall(err);
    }

//     err = addDirectory("", gVersion, "bin", fProgram, "", true);
//     logComment("addDirectory for bin: " + err);
    
//     registerChrome(CONTENT | DELAYED_CHROME, getFolder(fChrome, "annotations.jar"), "content/annotations/");
//     registerChrome(LOCALE | DELAYED_CHROME, getFolder(fChrome, "annotations.jar"), "locale/en-US/annotations/");
    
    
    if (getLastError() == SUCCESS) {
	err = performInstall(); 
	logComment("performInstall: " + err);
    }
    else {
	cancelInstall(err);
    }
}
